MethodChannelYandexAuth class

Реализация YandexAuthPlatform поверх method channel.

Преобразует PlatformException из нативного кода в типизированные исключения YandexAuthException.

Inheritance

Constructors

MethodChannelYandexAuth()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
Метод-канал для общения с нативной стороной.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logout() Future<void>
Сбрасывает состояние авторизации на стороне SDK.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn() Future<YandexAuthResult>
Запускает авторизацию через Яндекс.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited