YandexAuthPlatform class abstract

Платформенный интерфейс для реализации YandexAuth.

Конкретные реализации (например MethodChannelYandexAuth) регистрируются через instance.

Inheritance
  • Object
  • PlatformInterface
  • YandexAuthPlatform
Implementers

Constructors

YandexAuthPlatform()
Constructs a YandexAuthPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logout() Future<void>
Сбрасывает состояние авторизации на стороне SDK.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signIn() Future<YandexAuthResult>
Запускает авторизацию через Яндекс.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance YandexAuthPlatform
The default instance of YandexAuthPlatform to use.
getter/setter pair